## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 7;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           python-email-validator
Version:        2.0.0
Release:        %autorelease
Summary:        A robust email syntax and deliverability validation library

# The CC0-1.0 license is *not allowed* in Fedora for code, but this package
# falls under the following blanket exception:
#
#   Existing uses of CC0-1.0 on code files in Fedora packages prior to
#   2022-08-01, and subsequent upstream versions of those files in those
#   packages, continue to be allowed. We encourage Fedora package maintainers
#   to ask upstreams to relicense such files.
#
# https://gitlab.com/fedora/legal/fedora-license-data/-/issues/91#note_1151947383
#
# Upstream was asked to consider relicensing:
#
# Please consider an alternative license
# https://github.com/JoshData/python-email-validator/issues/113
License:        CC0-1.0
URL:            https://github.com/JoshData/python-email-validator
Source:         %{url}/archive/v%{version}/python-email-validator-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
# test_requirements.txt pins exact versions and includes unwanted coverage and
# linting dependencies, so we fall back to manual BuildRequires:
BuildRequires:  %{py3_dist pytest}

%global _description %{expand:
This library validates that a string is of the form name@example.com and
optionally checks that the domain name is set up to receive email. This is the
sort of validation you would want when you are identifying users by their email
address like on a registration/login form (but not necessarily for composing an
email message).

Key features:

  • Checks that an email address has the correct syntax – good for
    registration/login forms or other uses related to identifying users.
  • Gives friendly English error messages when validation fails that you can
    display to end-users.
  • Checks deliverability (optional): Does the domain name resolve? (You can
    override the default DNS resolver to add query caching.)
  • Supports internationalized domain names and internationalized local parts.
  • Rejects addresses with unsafe Unicode characters, obsolete email address
    syntax that you’d find unexpected, special use domain names like
    @localhost, and domains without a dot by default. This is an opinionated
    library!
  • Normalizes email addresses (important for internationalized and
    quoted-string addresses!)
  • Python type annotations are used.}

%description %{_description}

%package -n     python3-email-validator
Summary:        %{summary}

%description -n python3-email-validator %{_description}

%prep
%autosetup -n python-email-validator-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files email_validator

%check
# Even though we have disabled the “network” mark, these still require DNS.
ignore="${ignore-} --ignore=tests/test_deliverability.py"
ignore="${ignore-} --ignore=tests/test_main.py"
%pytest -v tests -m 'not network' ${ignore-}
# Just to be sure, since we have disabled some tests:
%pyproject_check_import

%files -n python3-email-validator -f %{pyproject_files}
%doc CHANGELOG.md README.md
%{_bindir}/email_validator

%changelog
* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jul 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-6
- Don’t package CONTRIBUTING.md; do package CHANGELOG.md

* Thu Jul 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-5
- Improve the package description

* Thu Jul 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-4
- Record that upstream was asked to consider relicensing

* Thu Jul 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-3
- Do not number the sole Source

* Wed Jun 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-1
- Update to 2.0.0 (close RHBZ#2203865)

* Wed Jun 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.3.1-1
- Update to 1.3.1

* Wed Jun 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.2.1-1
- Update to 1.2.1 (includes breaking changes from 1.x)

* Wed Jun 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.3-1
- Update to 1.1.3

* Wed Jun 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.1-11
- Update License to SPDX
- Fix up a few obsolete packaging practices
- Do not repeat the description text in the spec file
- Remove unnecessary and unwanted coverage dependencies
- Port to pyproject-rpm-macros

* Thu Jun 15 2023 Python Maint <python-maint@redhat.com> - 1.1.1-10
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> - 1.1.1-7
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 1.1.1-4
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jun 03 2020 Fabian Affolter <mail@fabian-affolter.ch> - 1.1.1-1
- Enable tests
- Update to new upstream release 1.1.1

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1.0.5-4
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Jan 07 2020 Fabian Affolter <mail@fabian-affolter.ch> - 1.0.5-2
- Implement changes from rhbz#1787419 to match rhbz#1733683

* Mon Jan 06 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.0.5-1
- Update to 1.0.5.
- Review fixes.

* Sat Jul 27 2019 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.0.4-1
- Initial package.

